# Roadmap

## Future Work

- Plugin system for new atlases or meta-analysis sources
- BIDS dataset support
- Optional type checking with `mypy`
- Support for probabilistic atlases
- Support for M/EEG sensors in addition to coordinates
- Extend study database with latest datasets (e.g., NeuroQuery)
- Fix skipped tests
